jQuery(document).ready(function(t){var e=t("body").data("portal-url"),r=t("#gdpr-consent-banner form").data("json-url");t.ajax({type:"GET",url:r,headers:{"Cache-Control":"no-cache"},cache:!1}).done(function(e){0==e.length?t("#gdpr-consent-banner").remove():t("#gdpr-consent-banner").show()});var a=function(){t.ajax({type:"GET",url:e+"/@@get_analytics",headers:{"Cache-Control":"no-cache"},cache:!1}).done(function(e){t("div#plone-analytics").html(e)}),t(".gdpr-iframe").length>0&&t.ajax({type:"GET",url:e+"/@@allow_iframes",headers:{"Cache-Control":"no-cache"},cache:!1}).done(function(e){!0==e&&(t(".gdpr-iframe-message").hide(),t(".gdpr-iframe").each(function(){t(this).attr("src",t(this).attr("gdpr-src")),t(this).attr("gdpr-height")?t(this).attr("height",t(this).attr("gdpr-height")):t(this).removeAttr("height"),t(this).attr("gdpr-width")?t(this).attr("width",t(this).attr("gdpr-width")):t(this).removeAttr("width")}))})};window.Faceted&&jQuery(Faceted.Events).bind(Faceted.Events.AJAX_QUERY_SUCCESS,function(){a()}),a()});
