// Fields description position between title and input.
form .form-text {
  margin-top: -0.4em;
  margin-bottom: 0.30em;
}

// Privacy related CSS
#cookies-form label span.required,
#cookies-form .form-text p,
#cookies-form #form-widgets-all_basic_cookies {
    display: none;
}

#gdpr-consent-banner {
    z-index: 999999;
    width: 100%;
    position: fixed;
    top: 0;
    left: 0;
    padding: 5px;
    background: orange;
    display:none;
}
