form.tabbed-form-with-toggle fieldset legend.dropdown-toggle {
  cursor: pointer;
}

form.tabbed-form-with-toggle fieldset:not(:nth-child(1)) legend.dropdown-toggle{
  &::after {
    display: inline-block;
    vertical-align: middle;
    transition: all .3s ease-in;
    transform-origin: center center;
    margin-left: 7px;
  }
  &.expanded{
    &:after{
      transform: rotate(180deg);
    }
  }
}
